Module: RiCal::Properties::Timezone

Included in:
Component::Timezone
Defined in:
lib/ri_cal/properties/timezone.rb

Overview

  • ©2009 Rick DeNatale
  • All rights reserved. Refer to the file README.txt for the license

Properties::Timezone provides property accessing methods for the Timezone class This source file is generated by the rical:gen_propmodules rake tasks, DO NOT EDIT

Defined Under Namespace

Modules: ClassMethods

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.included(mod) ⇒ Object

:nodoc:



141
142
143
# File 'lib/ri_cal/properties/timezone.rb', line 141

def self.included(mod) #:nodoc:
  mod.extend ClassMethods
end

Instance Method Details

#==(o) ⇒ Object

:nodoc:



115
116
117
118
119
120
121
122
123
# File 'lib/ri_cal/properties/timezone.rb', line 115

def ==(o) #:nodoc:
  if o.class == self.class
  (tzurl_property == o.tzurl_property) &&
  (last_modified_property == o.last_modified_property) &&
  (tzid_property == o.tzid_property)
  else
     super
  end
end

#add_date_times_to(required_timezones) ⇒ Object

:nodoc:



132
133
# File 'lib/ri_cal/properties/timezone.rb', line 132

def add_date_times_to(required_timezones) #:nodoc:
end

#export_properties_to(export_stream) ⇒ Object

:nodoc:



109
110
111
112
113
# File 'lib/ri_cal/properties/timezone.rb', line 109

def export_properties_to(export_stream) #:nodoc:
  export_prop_to(export_stream, "TZURL", @tzurl_property)
  export_prop_to(export_stream, "LAST-MODIFIED", @last_modified_property)
  export_prop_to(export_stream, "TZID", @tzid_property)
end

#initialize_copy(o) ⇒ Object

:nodoc:



125
126
127
128
129
130
# File 'lib/ri_cal/properties/timezone.rb', line 125

def initialize_copy(o) #:nodoc:
  super
  tzurl_property = tzurl_property && tzurl_property.dup
  last_modified_property = last_modified_property && last_modified_property.dup
  tzid_property = tzid_property && tzid_property.dup
end

#last_modifiedObject

return the value of the LAST-MODIFIED property which will be an instance of ZuluDateTime



67
68
69
# File 'lib/ri_cal/properties/timezone.rb', line 67

def last_modified
  last_modified_property ? last_modified_property.ruby_value : nil
end

#last_modified=(ruby_value) ⇒ Object

set the value of the LAST-MODIFIED property



61
62
63
# File 'lib/ri_cal/properties/timezone.rb', line 61

def last_modified=(ruby_value)
  self.last_modified_property= RiCal::PropertyValue::ZuluDateTime.convert(self, ruby_value)
end

#last_modified_propertyObject

return the the LAST-MODIFIED property which will be an instances of RiCal::PropertyValueZuluDateTime

[purpose (from RFC 2445)] This property specifies the date and time that the information associated with the calendar component was last revised in teh calendar store.

see RFC 2445 4.8.7.3 p 131



50
51
52
# File 'lib/ri_cal/properties/timezone.rb', line 50

def last_modified_property
  @last_modified_property
end

#last_modified_property=(property_value) ⇒ Object

set the LAST-MODIFIED property property value should be an instance of RiCal::PropertyValueZuluDateTime



56
57
58
# File 'lib/ri_cal/properties/timezone.rb', line 56

def last_modified_property=(property_value)
  @last_modified_property = property_value
end

#last_modified_property_from_string(line) ⇒ Object

:nodoc:



71
72
73
# File 'lib/ri_cal/properties/timezone.rb', line 71

def last_modified_property_from_string(line) # :nodoc:
  @last_modified_property = RiCal::PropertyValue::ZuluDateTime.new(self, line)
end

#mutual_exclusion_violationObject

:nodoc:



145
146
147
# File 'lib/ri_cal/properties/timezone.rb', line 145

def mutual_exclusion_violation #:nodoc:
  false
end

#tzidObject

return the value of the TZID property which will be an instance of String



34
35
36
# File 'lib/ri_cal/properties/timezone.rb', line 34

def tzid
  tzid_property ? tzid_property.ruby_value : nil
end

#tzid=(ruby_value) ⇒ Object

set the value of the TZID property



28
29
30
# File 'lib/ri_cal/properties/timezone.rb', line 28

def tzid=(ruby_value)
  self.tzid_property= RiCal::PropertyValue::Text.convert(self, ruby_value)
end

#tzid_propertyObject

return the the TZID property which will be an instances of RiCal::PropertyValueText

[purpose (from RFC 2445)] This property specifies the text value that uniquely indentifies the "VTIMEZONE" calendar component.

see RFC 2445 4.8.3.1 pp 97-98



17
18
19
# File 'lib/ri_cal/properties/timezone.rb', line 17

def tzid_property
  @tzid_property
end

#tzid_property=(property_value) ⇒ Object

set the TZID property property value should be an instance of RiCal::PropertyValueText



23
24
25
# File 'lib/ri_cal/properties/timezone.rb', line 23

def tzid_property=(property_value)
  @tzid_property = property_value
end

#tzid_property_from_string(line) ⇒ Object

:nodoc:



38
39
40
# File 'lib/ri_cal/properties/timezone.rb', line 38

def tzid_property_from_string(line) # :nodoc:
  @tzid_property = RiCal::PropertyValue::Text.new(self, line)
end

#tzurlObject

return the value of the TZURL property which will be an instance of Uri



100
101
102
# File 'lib/ri_cal/properties/timezone.rb', line 100

def tzurl
  tzurl_property ? tzurl_property.ruby_value : nil
end

#tzurl=(ruby_value) ⇒ Object

set the value of the TZURL property



94
95
96
# File 'lib/ri_cal/properties/timezone.rb', line 94

def tzurl=(ruby_value)
  self.tzurl_property= RiCal::PropertyValue::Uri.convert(self, ruby_value)
end

#tzurl_propertyObject

return the the TZURL property which will be an instances of RiCal::PropertyValueUri

[purpose (from RFC 2445)] The TZURL provies a means for a VTIMEZONE component to point to a network location that can be used to retrieve an up-to_date version of itself.

see RFC 2445 4.8.3.4 p 101



83
84
85
# File 'lib/ri_cal/properties/timezone.rb', line 83

def tzurl_property
  @tzurl_property
end

#tzurl_property=(property_value) ⇒ Object

set the TZURL property property value should be an instance of RiCal::PropertyValueUri



89
90
91
# File 'lib/ri_cal/properties/timezone.rb', line 89

def tzurl_property=(property_value)
  @tzurl_property = property_value
end

#tzurl_property_from_string(line) ⇒ Object

:nodoc:



104
105
106
# File 'lib/ri_cal/properties/timezone.rb', line 104

def tzurl_property_from_string(line) # :nodoc:
  @tzurl_property = RiCal::PropertyValue::Uri.new(self, line)
end